#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 store
version:              0.7.20
visibility:           public
id:                   store-0.7.20-HtPwmUcOOQZKQwqaB171qs
key:                  store-0.7.20-HtPwmUcOOQZKQwqaB171qs
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/mgsloan/store#readme
synopsis:             Fast binary serialization
category:             Serialization, Data
abi:                  0d3769085bd5218ec370f3e78916dedc
exposed:              True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer

hidden-modules:       Data.Store.Impl
import-dirs:          /usr/lib/ghc-9.6.6/site-local/store-0.7.20
library-dirs:         /usr/lib/ghc-9.6.6/site-local/store-0.7.20
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/store-0.7.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-store
hs-libraries:         HSstore-0.7.20-HtPwmUcOOQZKQwqaB171qs
depends:
    array-0.5.6.0 async-2.2.6-JFqXkyZWakA6MSvky6jlwB base-4.18.2.1
    base-orphans-0.9.3-AB1TTMQvhGuLLC2UWUBORD
    base64-bytestring-1.2.1.0-BWOGj3HDdwSDbLnS8UTB67
    bifunctors-5.6.3-K3SXGa9TDYQ5teuf9aA4ks bytestring-0.11.5.3
    containers-0.6.7 contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha1-0.11.101.0-5HTqHLT0Zf4Acm8DXUaDG1 deepseq-1.4.8.1
    directory-1.3.8.5 filepath-1.4.300.1 free-5.2-DaHCx1lHPp4c1iLjoTi4v
    ghc-prim-0.10.0 hashable-1.4.7.0-8qGpYVybfmaKH8giGSMaAG
    hspec-2.11.5-LAcpW14V5x92DJUdeVnlb
    hspec-smallcheck-0.5.3-6lEm7U5FkMuEdg5FwMjLUE integer-gmp-1.1
    lifted-base-0.2.3.12-LubbFGgfCFI2BoNFhQ5QMo
    monad-control-1.0.3.1-Ah73ESKiH1C3ayLrCvcag3
    mono-traversable-1.0.21.0-4AVokNrJdRrD6jNwgrzgJs
    network-3.1.4.0-10rvNinchMB4AwxOArhT4I
    primitive-0.9.1.0-CTO5MxhiVrsFEEvGOrOd6k
    resourcet-1.2.6-1xyvvIMDXXY2PZlggmi6VN
    safe-0.3.21-CJwI1nXd4mu5AecalHl564
    smallcheck-1.2.1.1-4lUlLiOcXtT4ZT5qzc3dGk
    store-core-0.4.4.7-FRY0Kv5CnI96uPLD9KkUgV
    syb-0.7.3-LrvXJMjYPlcHf68JytS4Q template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.7-JMijAGUD56uaCh66C6Lgg
    th-lift-instances-0.1.20-HSy0z4fMOT75vK4cN8EvfK
    th-orphans-0.13.17-JYtOPRimnXn5Kd3EgstlMb
    th-reify-many-0.1.10-Aw82NGU3ynnGM9ABIE03I5
    th-utilities-0.2.5.2-GrKCJyCxB1qFEspFqXozr2 time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-9qHVoc2smYt9flJ6feRxGY
    vector-0.13.2.0-AWRowWUrdYO1choGzrrEgg
    void-0.7.4-Ab78HEYVlxC2PerDGXO6Wd

haddock-interfaces:   /usr/share/doc/haskell-store/html/store.haddock
haddock-html:         /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

